
/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_SONDA_ID_GEN;

CREATE TABLE WWW_SONDA (
    ID             INTEGER NOT NULL,
    PYTANIE        VARCHAR(512) NOT NULL COLLATE PXW_PLK,
    PUBLIKACJA_OD  DATE NOT NULL,
    PUBLIKACJA_DO  DATE,
    UWAGI          VARCHAR(512) COLLATE PXW_PLK
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SONDA ADD CONSTRAINT WWW_SONDA_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_SONDA_DATY_IND ON WWW_SONDA (PUBLIKACJA_OD, PUBLIKACJA_DO);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: ID_SONDY_TRIG */
CREATE TRIGGER ID_SONDY_TRIG FOR WWW_SONDA
ACTIVE BEFORE INSERT POSITION 0
AS
begin

  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_SONDA_ID_GEN,1);

end
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SONDA TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_SONDA_ODPOWIEDZI_ID_GEN;

CREATE TABLE WWW_SONDA_ODPOWIEDZI (
    ID         INTEGER NOT NULL,
    ID_SONDY   INTEGER NOT NULL,
    ODPOWIEDZ  VARCHAR(512) NOT NULL COLLATE PXW_PLK,
    GLOSY      INTEGER DEFAULT          0 NOT NULL
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SONDA_ODPOWIEDZI ADD CONSTRAINT WWW_SONDA_ODP_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_SONDA_ODPOWIEDZI ADD CONSTRAINT WWW_SONDA_ODP_ID_SONDY_FK FOREIGN KEY (ID_SONDY) REFERENCES WWW_SONDA (ID) ON DELETE CASCADE ON UPDATE CASCADE
  USING INDEX ODPOWIEDZI_ID_SONDY_FK;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_SONDA_ODPOWIEDZI_GLOSY ON WWW_SONDA_ODPOWIEDZI (GLOSY);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_SONDA_ODPOWIEDZI_BI0 */
CREATE TRIGGER WWW_SONDA_ODPOWIEDZI_BI0 FOR WWW_SONDA_ODPOWIEDZI
ACTIVE BEFORE INSERT POSITION 0
AS
begin

  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_SONDA_ODPOWIEDZI_ID_GEN,1);

end
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD ID TABLE WWW_SONDA_ODPOWIEDZI
'identyfikator pytania';

DESCRIBE FIELD ID_SONDY TABLE WWW_SONDA_ODPOWIEDZI
'identyfikator sondy';

DESCRIBE FIELD ODPOWIEDZ TABLE WWW_SONDA_ODPOWIEDZI
'odpowiedz
';

DESCRIBE FIELD GLOSY TABLE WWW_SONDA_ODPOWIEDZI
'liczba glosow';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_SONDA_ODPOWIEDZI TO WWW_ROLE;


