/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_PARAM_GRUPY_ID_GEN;

CREATE TABLE WWW_PARAM_GRUPY (
    ID     INTEGER NOT NULL,
    NAZWA  STRING60_D /* STRING60_D = VARCHAR(60) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PARAM_GRUPY ADD CONSTRAINT WWW_PARAM_GRUPY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_PARAM_GRUPY_BI */
CREATE TRIGGER WWW_PARAM_GRUPY_BI FOR WWW_PARAM_GRUPY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_PARAM_GRUPY_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PARAM_GRUPY TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_PARAMETRY_ID_GEN;

CREATE TABLE WWW_PARAMETRY (
    ID        INTEGER NOT NULL,
    GRUPA_ID  INTEGER,
    NAZWA     STRING200_D /* STRING200_D = VARCHAR(200) */,
    UKRYJ     BOOLEAN_D DEFAULT 0 NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    TYP       SMALLINT,
    LP        SMALLINT,
    CDATE     DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */,
    MDATE     DATA_TIME_D /* DATA_TIME_D = TIMESTAMP */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PARAMETRY ADD CONSTRAINT WWW_PARAMETRY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_PARAMETRY_BI */
CREATE TRIGGER WWW_PARAMETRY_BI FOR WWW_PARAMETRY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_PARAMETRY_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD CDATE TABLE WWW_PARAMETRY
'Wzorzec dla pl zawierajcych dat i czas';

DESCRIBE FIELD MDATE TABLE WWW_PARAMETRY
'Wzorzec dla pl zawierajcych dat i czas';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PARAMETRY TO WWW_ROLE;



/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/


CREATE GENERATOR WWW_PARAM_WART_ID_GEN;

CREATE TABLE WWW_PARAM_WART (
    ID        INTEGER NOT NULL,
    PARAM_ID  INTEGER DEFAULT 0,
    WARTOSC   STRING200_D NOT NULL COLLATE PXW_PLK /* STRING200_D = VARCHAR(200) */
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_PARAM_WART ADD CONSTRAINT WWW_PARAM_WART_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_PARAM_WART_BI */
CREATE TRIGGER WWW_PARAM_WART_BI FOR WWW_PARAM_WART
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_PARAM_WART_ID_GEN,1);
END
^


SET TERM ; ^



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_PARAM_WART TO WWW_ROLE;




/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/



CREATE TABLE WWW_TOWARY_PARAMS (
    TOWAR_ID  INTEGER NOT NULL,
    PARAM_ID  INTEGER NOT NULL,
    WART_ID   INTEGER NOT NULL,
    LP        SMALLINT
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_TOWARY_PARAMS ADD CONSTRAINT WWW_TOWARY_PARAMS_UNQ UNIQUE (TOWAR_ID, PARAM_ID, WART_ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_TOWARY_PARAMS ADD CONSTRAINT WWW_TOWARY_PARAMS_PARAM_FK FOREIGN KEY (PARAM_ID) REFERENCES WWW_PARAMETRY (ID) ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE WWW_TOWARY_PARAMS ADD CONSTRAINT WWW_TOWARY_PARAMS_TOWAR_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY (ID) ON DELETE CASCADE ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_TOWARY_PARAMS_PWART_IND ON WWW_TOWARY_PARAMS (WART_ID);


/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_TOWARY_PARAMS TO WWW_ROLE;





/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE TABLE WWW_GRUPYT_SERWISY (
    GRUPA_ID      INTEGER NOT NULL,
    EXT           BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    SERWIS        VARCHAR(32) NOT NULL,
    SERWIS_GRUPA  INTEGER NOT NULL
);




/******************************************************************************/
/****                          Unique Constraints                          ****/
/******************************************************************************/

ALTER TABLE WWW_GRUPYT_SERWISY ADD CONSTRAINT WWW_GRUPYT_SERWISY_UNQ UNIQUE (GRUPA_ID, EXT, SERWIS);


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_GRUPYT_SERWISY_GRUPA_IND ON WWW_GRUPYT_SERWISY (GRUPA_ID, EXT);
CREATE INDEX WWW_GRUPYT_SERWISY_SERWIS_IND ON WWW_GRUPYT_SERWISY (SERWIS, SERWIS_GRUPA);


/* Fields descriptions */

DESCRIBE FIELD EXT TABLE WWW_GRUPYT_SERWISY
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_GRUPYT_SERWISY TO WWW_ROLE;


/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

CREATE GENERATOR WWW_OFERTY_ID_GEN;

CREATE TABLE WWW_OFERTY (
    ID            INTEGER NOT NULL,
    FORMAT        STRING20_D COLLATE PXW_PLK /* STRING20_D = VARCHAR(20) */,
    NAZWA         VARCHAR(128) NOT NULL,
    KODOWANIE     STRING20_D NOT NULL COLLATE PXW_PLK /* STRING20_D = VARCHAR(20) */,
    BRANZA        STRING30_D NOT NULL /* STRING30_D = VARCHAR(30) */,
    RODZAJ        STRING10_D NOT NULL /* STRING10_D = VARCHAR(10) */,
    CENA_ID       INTEGER,
    USE_CACHE     BOOLEAN_D NOT NULL /* BOOLEAN_D = SMALLINT DEFAULT 0 NOT NULL CHECK    (VALUE IN (0,1)) */,
    CACHE_PERIOD  INTEGER,
    GRUPA_ID      INTEGER,
    CENNIKI       BLOB SUB_TYPE 2 SEGMENT SIZE 512,
    ATRYBUTY      BLOB SUB_TYPE 2 SEGMENT SIZE 512 NOT NULL,
    DANE          BLOB SUB_TYPE 2 SEGMENT SIZE 512,
    UWAGI         VARCHAR(512),
    CDATE         TIMESTAMP NOT NULL,
    MDATE         TIMESTAMP NOT NULL,
    DOSTEPNOSC    SMALLINT,
    STAN_TOWARU   SMALLINT,
    MAGAZYNY      BLOB SUB_TYPE 2 SEGMENT SIZE 256,
    REQ_PARAM     INTEGER
);




/******************************************************************************/
/****                             Primary Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_OFERTY ADD CONSTRAINT WWW_OFERTY_PK PRIMARY KEY (ID);


/******************************************************************************/
/****                             Foreign Keys                             ****/
/******************************************************************************/

ALTER TABLE WWW_OFERTY ADD CONSTRAINT WWW_OFERTY_CENA_ID_FK FOREIGN KEY (CENA_ID) REFERENCES GM_CENY (ID) ON DELETE SET NULL ON UPDATE CASCADE;
ALTER TABLE WWW_OFERTY ADD CONSTRAINT WWW_OFERTY_REQ_PARAM_FK FOREIGN KEY (REQ_PARAM) REFERENCES WWW_PARAMETRY (ID) ON DELETE SET NULL ON UPDATE CASCADE;


/******************************************************************************/
/****                               Indices                                ****/
/******************************************************************************/

CREATE INDEX WWW_OFERTY_DATY_IND ON WWW_OFERTY (CDATE, MDATE);
CREATE UNIQUE INDEX WWW_OFERTY_NAZWA_IND ON WWW_OFERTY (FORMAT, NAZWA);


/******************************************************************************/
/****                               Triggers                               ****/
/******************************************************************************/


SET TERM ^ ;


/******************************************************************************/
/****                         Triggers for tables                          ****/
/******************************************************************************/



/* Trigger: WWW_OFERTY_BI */
CREATE TRIGGER WWW_OFERTY_BI FOR WWW_OFERTY
ACTIVE BEFORE INSERT POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
    NEW.ID = GEN_ID(WWW_OFERTY_ID_GEN,1);
END
^


SET TERM ; ^



/* Fields descriptions */

DESCRIBE FIELD USE_CACHE TABLE WWW_OFERTY
'Wzr typu dla pl zawierajcych warto logiczn: tak lub nie';



/******************************************************************************/
/****                              Privileges                              ****/
/******************************************************************************/


/* Privileges of roles */
GRANT ALL ON WWW_OFERTY TO WWW_ROLE;



/******************************************************************************/

ALTER TABLE WWW_STATS DROP CONSTRAINT WWW_STATS_TOWAR_ID_FK;
ALTER TABLE WWW_STATS ADD CONSTRAINT WWW_STATS_TOWAR_ID_FK FOREIGN KEY (TOWAR_ID) REFERENCES GM_TOWARY(ID) ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE WWW_GRUPYT_EXT DROP RADAR_ID;
ALTER TABLE WWW_GRUPYT DROP RADAR_ID;

update RDB$RELATION_FIELDS set RDB$FIELD_SOURCE = 'STRING200_D' where (RDB$FIELD_NAME = 'FIRMA_NAZWA') and (RDB$RELATION_NAME = 'WWW_REG');


